/**
 * @file    GoGdpProfilePointCloud.cpp
 *
 * @internal
 * Copyright (C) 2022-2023 by LMI Technologies Inc.
 * Licensed under the MIT License.
 * Redistributed files must retain the above copyright notice.
 */
#include <GoPxLSdk/GoGdpMsg/GoGdpProfilePointCloud.h>
#include <kApi/Data/kArray1.h>

namespace GoPxLSdk
{
    GoGdpProfilePointCloud::GoGdpProfilePointCloud()
        : GoGdpProfileBase(MessageType::PROFILE_POINT_CLOUD)
    {
        ranges.Reset();
        intensities.Reset();
    }

    void GoGdpProfilePointCloud::Deserialize(kSerializer serializer)
    {
        const kPoint16s* points;

        GoGdpProfileBase::Deserialize(serializer);

        try
        {
            GoTest(kArray1_Construct(ranges.Ref(), kTypeOf(kPoint16s), Width(), kAlloc_App()));
            points = kArray1_DataT(ranges, kPoint16s);

            // Treat the kPoint16s array as an array of 16s.
            GoTest(kSerializer_Read16sArray(serializer, (k16s*) points, Width() * 2));

            if (!kSerializer_ReadCompleted(serializer) && IntensityWidth() > 0)
            {
                GoTest(kArray1_Construct(intensities.Ref(), kTypeOf(k8u), IntensityWidth(), kAlloc_App()));
                GoTest(kSerializer_Read8uArray(serializer, kArray1_DataT(intensities, k8u), IntensityWidth()));
            }
        }
        catch (const Go::Exception&)
        {
            GoRethrow("Failed to deserialize Profile Point Cloud GDP message.");
        }
    }

    const kArray1 GoGdpProfilePointCloud::Ranges() const
    {
        return ranges.Get();
    }

    const kArray1 GoGdpProfilePointCloud::Intensities() const
    {
        return intensities.Get();
    }
}