/**
 * @file    GoGdpBoundingBox.cs
 *
 * @internal
 * Copyright (C) 2022-2023 by LMI Technologies Inc.
 * Licensed under the MIT License.
 * Redistributed files must retain the above copyright notice.
 */
namespace GoPxLSdk.GoGdpMsg
{
    public class GoGdpBoundingBox
    {
        /// <summary>Get X-coordinate of the origin.</summary>
        /// <returns>X-coordinate value of the bounding box origin.</returns>
        public double X { get; private set; }

        /// <summary>Get Y-coordinate of the origin.</summary>
        /// <returns>Y-coordinate value of the bounding box origin.</returns>
        public double Y { get; private set; }

        /// <summary>Get Z-coordinate of the origin.</summary>
        /// <returns>Z-coordinate value of the bounding box origin.</returns>
        public double Z { get; private set; }

        /// <summary>Get the bounding box size along the x-axis.</summary>
        /// <returns>the width of bounding box .</returns>
        public double Width { get; private set; }

        /// <summary>Get the bounding box size along the y-axis.</summary>
        /// <returns>the length of bounding box.</returns>
        public double Length { get; private set; }

        /// <summary>Get the bounding box size along the z-axis.</summary>
        /// <returns>the height of bounding box.</returns>
        public double Height { get; private set; }

        public GoGdpBoundingBox()
        { }

        internal GoGdpBoundingBox(double x, double y, double z, double width, double length, double height)
        {
            X = x;
            Y = y;
            Z = z;
            Width = width;
            Length = length;
            Height = height;
        }

        /// <summary>Deserialize the bounding box data.</summary>
        /// <param name="serializer">The serializer to read.</param>
        internal void Deserialize(GoBinaryReader serializer)
        {
            X = (double)serializer.ReadSingle();
            Y = (double)serializer.ReadSingle();
            Z = (double)serializer.ReadSingle();

            Width = (double)serializer.ReadSingle();
            Length = (double)serializer.ReadSingle();
            Height = (double)serializer.ReadSingle();
        }

        public override bool Equals(object obj)
        {
            return obj is GoGdpBoundingBox box &&
                   X == box.X &&
                   Y == box.Y &&
                   Z == box.Z &&
                   Width == box.Width &&
                   Length == box.Length &&
                   Height == box.Height;
        }

        public override int GetHashCode()
        {
            int hashCode = -162955930;
            hashCode = hashCode * -1521134295 + X.GetHashCode();
            hashCode = hashCode * -1521134295 + Y.GetHashCode();
            hashCode = hashCode * -1521134295 + Z.GetHashCode();
            hashCode = hashCode * -1521134295 + Width.GetHashCode();
            hashCode = hashCode * -1521134295 + Length.GetHashCode();
            hashCode = hashCode * -1521134295 + Height.GetHashCode();
            return hashCode;
        }

        public static bool operator==(GoGdpBoundingBox a, GoGdpBoundingBox b)
        {
            return a.Equals(b);
        }

        public static bool operator !=(GoGdpBoundingBox a, GoGdpBoundingBox b)
        {
            return !a.Equals(b);
        }
    }
}