/**
 * @file    GoGdpFeatureLine.cs
 *
 * @internal
 * Copyright (C) 2022-2023 by LMI Technologies Inc.
 * Licensed under the MIT License.
 * Redistributed files must retain the above copyright notice.
 */
namespace GoPxLSdk.GoGdpMsg
{
    public class GoGdpFeatureLine : GoGdpMsg
    {
        /// <summary>Get x coordinate of the position.</summary>
        /// <returns>x coordinate value of the position.</returns>
        public double PositionX { get; private set; }

        /// <summary>Get y coordinate of the position.</summary>
        /// <returns>y coordinate value of the position.</returns>
        public double PositionY { get; private set; }

        /// <summary>Get z coordinate of the position.</summary>
        /// <returns>z coordinate value of the position.</returns>
        public double PositionZ { get; private set; }

        /// <summary>Get x component of direction vector.</summary>
        /// <returns>x component of direction vector.</returns>
        public double DirectionX { get; private set; }

        /// <summary>Get y component of direction vector.</summary>
        /// <returns>y component of direction vector.</returns>
        public double DirectionY { get; private set; }

        /// <summary>Get z component of direction vector.</summary>
        /// <returns>z component of direction vector.</returns>
        public double DirectionZ { get; private set; }

        /// <summary>Constructs class GoGdpFeatureLine.</summary>
        public GoGdpFeatureLine()
            : base(MessageType.LineFeature)
        { }

        internal GoGdpFeatureLine(GoPoint3d64f position, GoPoint3d64f direction)
            : base(MessageType.LineFeature)
        {
            PositionX = position.X;
            PositionY = position.Y;
            PositionZ = position.Z;

            DirectionX = direction.X;
            DirectionY = direction.Y;
            DirectionZ = direction.Z;
        }

        /// <summary>Deserialize gdp line feature message.</summary>
        /// <param name="reader">The serializer to read.</param>
        internal override void Deserialize(GoBinaryReader reader)
        {
            base.Deserialize(reader);

            PositionX = reader.ReadDouble();
            PositionY = reader.ReadDouble();
            PositionZ = reader.ReadDouble();
            DirectionX = reader.ReadDouble();
            DirectionY = reader.ReadDouble();
            DirectionZ = reader.ReadDouble();
        }
    }
}