/**
 * @file    GoGdpNull.cs
 *
 * @internal
 * Copyright (C) 2022-2023 by LMI Technologies Inc.
 * Licensed under the MIT License.
 * Redistributed files must retain the above copyright notice.
 */
namespace GoPxLSdk.GoGdpMsg
{
    public class GoGdpNull : GoGdpMsg
    {
        /// <summary>Get error status.</summary>
        public int ErrorStatus { get; internal set; }

        /// <summary>Constructs GoGdpNull.</summary>
        public GoGdpNull()
            : base(MessageType.NullType)
        { }

        /// <summary>Constructs GoGdpNull.</summary>
        internal GoGdpNull(int errorStatus)
            : base(MessageType.NullType)
        {
            ErrorStatus = errorStatus;
        }

        /// <summary>Deserialize null message.</summary>
        /// <param name="serializer">The serializer to read.</param>
        internal override void Deserialize(GoBinaryReader serializer)
        {
            base.Deserialize(serializer);
            serializer.BeginRead<ushort>(true);

            try
            {
                ErrorStatus = serializer.ReadInt32();
            }
            finally
            {
                serializer.EndRead();
            }
        }
    }
}
