/**
 * @file    GoGdpProfileUniform.cs
 *
 * @internal
 * Copyright (C) 2022-2023 by LMI Technologies Inc.
 * Licensed under the MIT License.
 * Redistributed files must retain the above copyright notice.
 */
using System;
using System.Collections.Generic;

namespace GoPxLSdk.GoGdpMsg
{
    public class GoGdpProfileUniform : GoGdpProfileBase
    {
        /// <summary>Get profile ranges.</summary>
        /// <returns>ranges array.</returns>
        public short[] Ranges { get; internal set; }

        /// <summary>Get profile intensities.</summary>
        /// <returns>intensities array.</returns>
        public byte[] Intensities { get; internal set; }

        /// <summary>Constructs GoGdpProfileUniform.</summary>
        public GoGdpProfileUniform()
            : base(MessageType.UniformProfile)
        { }

        /// <summary>Deserialize profile uniform message.</summary>
        /// <param name="serializer">The serializer to read.</param>
        internal override void Deserialize(GoBinaryReader serializer)
        {
            base.Deserialize(serializer);

            Ranges = new short[Width];
            byte[] buffer = serializer.ReadBytes((int)Width * 2);
            Buffer.BlockCopy(buffer, 0, Ranges, 0, buffer.Length);

            if (!serializer.IsReadCompleted && IntensityWidth > 0)
            {
                Intensities = serializer.ReadBytes((int)IntensityWidth);
            }
        }
    }
}