/**
 * @file    GoGdpSurfaceUniform.cs
 *
 * @internal
 * Copyright (C) 2022-2023 by LMI Technologies Inc.
 * Licensed under the MIT License.
 * Redistributed files must retain the above copyright notice.
 */
namespace GoPxLSdk.GoGdpMsg
{
    public class GoGdpSurfaceUniform : GoGdpSurfaceBase
    {
        /// <summary>Get surface ranges.</summary>
        /// <returns>surface ranges array.</returns>
        public short[,] Ranges { get; internal set; }

        /// <summary>Get surface intensities.</summary>
        /// <returns>surface intensities array.</returns>
        public byte[,] Intensities { get; internal set; }

        /// <summary>Constructs GoGdpSurfaceUniform.</summary>
        public GoGdpSurfaceUniform()
            : base(MessageType.UniformSurface)
        { }

        /// <summary>Deserialize surface uniform message.</summary>
        /// <param name="serializer">The serializer to read.</param>
        internal override void Deserialize(GoBinaryReader serializer)
        {
            base.Deserialize(serializer);

            // This closes the surface attributes read section.
            serializer.EndRead();

            var buffer = serializer.ReadBytes((int)(Length * Width * sizeof(short)));
            Ranges = new short[Length, Width];
            System.Buffer.BlockCopy(buffer, 0, Ranges, 0, buffer.Length);

            long intensitySize = IntensityLength * IntensityWidth;
            if (!serializer.IsReadCompleted && intensitySize > 0)
            {
                var intensitiesBuffer = serializer.ReadBytes((int)intensitySize);
                Intensities = new byte[IntensityLength, IntensityWidth];
                System.Buffer.BlockCopy(intensitiesBuffer, 0, Intensities, 0, intensitiesBuffer.Length);
            }
        }
    }
}