/**
 * @file    GoInstance.cs
 *
 * @internal
 * Copyright (C) 2022-2023 by LMI Technologies Inc.
 * Licensed under the MIT License.
 * Redistributed files must retain the above copyright notice.
 */
using GoPxLSdk.Internal;
using MessagePack;
using Newtonsoft.Json;
using System.Net;

namespace GoPxLSdk
{
    public class GoInstance
    {
        /// <summary>Gets or setsthe Ip address of GoPxL instance.</summary>
        /// <returns>Ip address of GoPxL instance.</returns>
        [JsonConverter(typeof(IpAddressJsonConverter))]
        [JsonProperty("Address")]
        public IPAddress IpAddress { get; set; }

        /// <summary>Gets or sets the unique Application Id of GoPxL instance.</summary>
        /// <returns>Application Id of GoPxL instance.</returns>
        public string AppId { get; set; }

        /// <summary>Gets or sets the Application name of GoPxL instance.</summary>
        /// <returns>Application name of GoPxL instance.</returns>
        public string AppName { get; set; }

        /// <summary>Gets or sets the Application version of GoPxL instance.</summary>
        /// <returns>Application version of GoPxL instance.</returns>
        public string AppVersion { get; set; }

        /// <summary>Gets or sets the Control port of GoPxL instance.</summary>
        /// <returns>Control port of GoPxL instance.</returns>
        public uint ControlPort { get; set; }

        /// <summary>Gets or sets the Serial Number of GoPxL instance.</summary>
        /// <returns>Serial Number of GoPxL instance.</returns>
        [JsonConverter(typeof(SerialNumberJsonConverter))]
        public uint SerialNumber { get; set; }

        /// <summary>Gets or sets the Device model of GoPxL instance.</summary>
        /// <returns>Device model of GoPxL instance.</returns>
        public string DeviceModel { get; set; }

        /// <summary>Gets or sets if the Dhcp of GoPxL instance is enabled or not.</summary>
        /// <returns>True if enabled, false otherwise.</returns>
        [JsonProperty("Dhcp")]
        public bool IsDhcp { get; set; }

        /// <summary>Gets or sets the Gateway of GoPxL instance.</summary>
        /// <returns>Gateway of GoPxL instance.</returns>
        [JsonConverter(typeof(IpAddressJsonConverter))]
        public IPAddress Gateway { get; set; }

        /// <summary>Gets  or sets the Gocator Data Protocol (Gdp) port of GoPxL instance.</summary>
        /// <returns>Gdp port of GoPxL instance.</returns>
        public uint GdpPort { get; set; }

        /// <summary>Gets or sets if there was an IP address conflict.</summary>
        /// <returns>True if the IP address was automatically assigned due to an address conflict,</returns>
        [JsonProperty("AddressConflict")]
        public bool IsAddressConflict { get; set; }

        /// <summary>Gets or sets if the GoPxL instance is connected remotely.</summary>
        /// <returns>True if LMI device is remotely connected/controlled from another GoPxL instance,</returns>
        public bool IsRemote { get; set; }

        /// <summary>Gets or sets the Mask of GoPxL instance.</summary>
        /// <returns>Mask of GoPxL instance.</returns>
        [JsonConverter(typeof(IpAddressJsonConverter))]
        public IPAddress Mask { get; set; }

        /// <summary>Gets or sets the Web port of GoPxL instance.</summary>
        /// <returns>Webport of GoPxL instance.</returns>
        public uint WebPort { get; set; }

        public GoInstance()
        { }
    }
}