/**
 * @file    GoTimer.cs
 *
 * @internal
 * Copyright (C) 2022-2023 by LMI Technologies Inc.
 * Licensed under the MIT License.
 * Redistributed files must retain the above copyright notice.
 */
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace GoPxLSdk
{
    internal class GoTimer
    {
        private readonly Stopwatch _watch = new Stopwatch();
        private TimeSpan _timeout;

        public bool IsExpired => _watch.Elapsed > _timeout;

        /// <summary>
        /// The remaining time in milliseconds.
        /// </summary>
        public long Remaining => (long)_timeout.TotalMilliseconds - _watch.ElapsedMilliseconds;

        public GoTimer() { }

        public void Start(int timeoutMilliseconds) => Start(TimeSpan.FromMilliseconds(timeoutMilliseconds));

        public void Start(long timeoutMilliseconds) => Start(TimeSpan.FromMilliseconds(timeoutMilliseconds));
        public void Start(double timeoutMilliseconds) => Start(TimeSpan.FromMilliseconds(timeoutMilliseconds));

        public void Start(TimeSpan timeout)
        {
            _timeout = timeout;
            _watch.Start();
        }

        public void Restart(int timeoutMilliseconds) => Restart(TimeSpan.FromMilliseconds(timeoutMilliseconds));

        public void Restart(long timeoutMilliseconds) => Restart(TimeSpan.FromMilliseconds(timeoutMilliseconds));
        public void Restart(double timeoutMilliseconds) => Restart(TimeSpan.FromMilliseconds(timeoutMilliseconds));

        public void Restart(TimeSpan timeout)
        {
            _timeout = timeout;
            _watch.Restart();
        }

        public void Stop() => _watch.Stop();

        public void Reset() => _watch.Reset();
    }
}
