/**
 * @file    IpAddressJsonConverter.cs
 *
 * @internal
 * Copyright (C) 2022-2023 by LMI Technologies Inc.
 * Licensed under the MIT License.
 * Redistributed files must retain the above copyright notice.
 */
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Text;
using System.Threading.Tasks;

namespace GoPxLSdk.Internal
{
    internal class IpAddressJsonConverter : JsonConverter
    {
        public override bool CanConvert(Type objectType)
        {
            if (objectType == typeof(IPAddress)) return true;

            return false;
        }

        public override object ReadJson(JsonReader reader, Type objectType, object existingValue, JsonSerializer serializer)
        {
            if (objectType == typeof(IPAddress))
            {
                string value = JToken.Load(reader).ToString();
                if (string.IsNullOrEmpty(value))
                    return null;

                return IPAddress.Parse(value);
            }

            throw new NotImplementedException();
        }

        public override void WriteJson(JsonWriter writer, object value, JsonSerializer serializer)
        {
            // convert an IPAddress object to a string representation of itself and Write it to the serialiser
            if (value.GetType() == typeof(IPAddress))
            {
                if (value == null || string.IsNullOrEmpty(value.ToString()))
                {
                    JToken.FromObject("").WriteTo(writer);
                    return;
                }
                else
                {
                    JToken token = JToken.FromObject(value.ToString());
                    token.WriteTo(writer);
                    return;
                }
            }

            throw new NotImplementedException();
        }
    }
}
